==> cdi-tck-impl-1.2.9.Final-sources.jar: org/jboss/cdi/tck/tests/lookup/injection/enterprise/SessionBeanInjectionOrderingTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.enterprise;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.FIELDS_INITIALIZER_METHODS;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecAssertions;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@Test(groups = INTEGRATION)
@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class SessionBeanInjectionOrderingTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(SessionBeanInjectionOrderingTest.class).build();
    }

    @Test
    @SpecAssertion(section = FIELDS_INITIALIZER_METHODS, id = "bb")
    public void testInitializerCalledAfterFieldInjectionOfSuperclass() {
        MegaPoorHenHouseLocal house = getContextualReference(MegaPoorHenHouseLocal.class);
        assert house.isInitializerCalledAfterSuperclassInjection();
    }

    @Test
    @SpecAssertion(section = FIELDS_INITIALIZER_METHODS, id = "bf")
    public void testPostConstructCalledAfterInitializerOfSuperclass() {
        assert getContextualReference(MegaPoorHenHouseLocal.class).isPostConstructCalledAfterSuperclassInitializer();
    }

    @Test
    @SpecAssertions({ @SpecAssertion(section = FIELDS_INITIALIZER_METHODS, id = "bc"), @SpecAssertion(section = FIELDS_INITIALIZER_METHODS, id = "bd") })
    public void testInitializerCalledAfterResourceInjection() {
        assert getContextualReference(InjectedSessionBeanLocal.class).isInitializerCalledAfterResourceInjection();
    }
}

==> cdi-tck-impl-2.0.0.Final-sources.jar: org/jboss/cdi/tck/tests/lookup/injection/enterprise/SessionBeanInjectionOrderingTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.enterprise;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.FIELDS_INITIALIZER_METHODS_EE;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecAssertions;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@Test(groups = INTEGRATION)
@SpecVersion(spec = "cdi", version = "2.0-PFD")
public class SessionBeanInjectionOrderingTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(SessionBeanInjectionOrderingTest.class).build();
    }

    @Test
    @SpecAssertion(section = FIELDS_INITIALIZER_METHODS_EE, id = "bb")
    public void testInitializerCalledAfterFieldInjectionOfSuperclass() {
        MegaPoorHenHouseLocal house = getContextualReference(MegaPoorHenHouseLocal.class);
        assert house.isInitializerCalledAfterSuperclassInjection();
    }

    @Test
    @SpecAssertion(section = FIELDS_INITIALIZER_METHODS_EE, id = "bf")
    public void testPostConstructCalledAfterInitializerOfSuperclass() {
        assert getContextualReference(MegaPoorHenHouseLocal.class).isPostConstructCalledAfterSuperclassInitializer();
    }

    @Test
    @SpecAssertions({ @SpecAssertion(section = FIELDS_INITIALIZER_METHODS_EE, id = "bc"), @SpecAssertion(section = FIELDS_INITIALIZER_METHODS_EE, id = "bd") })
    public void testInitializerCalledAfterResourceInjection() {
        assert getContextualReference(InjectedSessionBeanLocal.class).isInitializerCalledAfterResourceInjection();
    }
}
